==> user-facade-1.0.0-sources.jar: com/bxm/user/facade/service/UserService.java <==
package com.bxm.user.facade.service;

import com.bxm.user.facade.Constants;
import com.bxm.user.facade.DevRequest;
import com.bxm.user.facade.SdkInitCache;
import com.bxm.user.facade.UserProfile;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 用户信息<br/>
 *
 * @author kerry.jiang
 * @date 2020/9/21 11:32
 */
@FeignClient(Constants.SERVER_NAME)
public interface UserService {

    /**
     * 获取用户信息<br/>
     *
     * @param request
     * @return com.bxm.adx.facade.model.dev.UserProfile
     */
    @RequestMapping(path = "/userService/getUser", method = RequestMethod.POST)
    UserProfile getUser(@RequestBody DevRequest request);

    /**
     * 获取SDK初始化信息（推荐）<br/>
     *
     * @param request 设备号相关信息
     * @return com.bxm.adx.facade.model.dev.SdkInitCache
     */
    @RequestMapping(path = "/userService/getSdkInit", method = RequestMethod.POST)
    SdkInitCache getSdkInit(@RequestBody DevRequest request);

    /**
     * 获取SDK初始化信息<br/>
     *
     * @param uid @see com.bxm.adx.facade.service.UserService.getUser()
     * @return com.bxm.adx.facade.model.dev.SdkInitCache
     */
    @RequestMapping(path = "/userService/getSdkInitByUid", method = RequestMethod.GET)
    SdkInitCache getSdkInitByUid(@RequestParam(value = "uid", required = true) String uid);

    /**
     * 获取SDK初始化时的已安装APP包名列表（推荐）<br/>
     * 仅支持安卓<br/>
     *
     * @param request 设备号相关信息
     * @return java.util.List<java.lang.String>
     */
    @RequestMapping(path = "/userService/getInstalledList", method = RequestMethod.POST)
    List<String> getInstalledList(@RequestBody DevRequest request);

    /**
     * 获取SDK初始化时的已安装APP包名列表<br/>
     * 仅支持安卓<br/>
     *
     * @param uid @see com.bxm.adx.facade.service.UserService.getUser()
     * @return java.util.List<java.lang.String>
     */
    @RequestMapping(path = "/userService/getInstalledListByUid", method = RequestMethod.GET)
    List<String> getInstalledListByUid(@RequestParam(value = "uid", required = true) String uid);

    /**
     * 获取用户的个推标签
     * @param request 设备号相关信息
     * @return 标签列表
     */
    @PostMapping("/userService/getTagsForGetui")
    List<String> getTagsForGetui(@RequestBody DevRequest request);
}

==> user-facade-1.0.3-sources.jar: com/bxm/user/facade/service/UserService.java <==
package com.bxm.user.facade.service;

import java.util.List;

import com.bxm.user.facade.*;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

/**
 * 用户信息<br/>
 *
 * @author kerry.jiang
 * @date 2020/9/21 11:32
 */
@FeignClient(Constants.SERVER_NAME)
public interface UserService {

    /**
     * 获取用户信息<br/>
     *
     * @param request
     * @return com.bxm.user.facade.UserProfile
     */
    @RequestMapping(path = "/userService/getUser", method = RequestMethod.POST)
    UserProfile getUser(@RequestBody DevRequest request);

    /**
     * 获取SDK初始化信息（推荐）<br/>
     *
     * @param request 设备号相关信息
     * @return com.bxm.user.facade.SdkInitCache
     */
    @RequestMapping(path = "/userService/getSdkInit", method = RequestMethod.POST)
    SdkInitCache getSdkInit(@RequestBody DevRequest request);

    /**
     * 获取SDK初始化信息<br/>
     *
     * @param uid {@link UserService#getUser(DevRequest) }
     * @return com.bxm.user.facade.SdkInitCache
     */
    @RequestMapping(path = "/userService/getSdkInitByUid", method = RequestMethod.GET)
    SdkInitCache getSdkInitByUid(@RequestParam(value = "uid", required = true) String uid);

    /**
     * 获取SDK初始化时的已安装APP包名列表（推荐）<br/>
     * 仅支持安卓<br/>
     *
     * @param request 设备号相关信息
     * @return java.util.List<java.lang.String>
     */
    @RequestMapping(path = "/userService/getInstalledList", method = RequestMethod.POST)
    List<String> getInstalledList(@RequestBody DevRequest request);

    /**
     * 获取SDK初始化时的已安装APP包名列表<br/>
     * 仅支持安卓<br/>
     *
     * @param uid {@link UserService#getUser(DevRequest) }
     * @return java.util.List<java.lang.String>
     */
    @RequestMapping(path = "/userService/getInstalledListByUid", method = RequestMethod.GET)
    List<String> getInstalledListByUid(@RequestParam(value = "uid", required = true) String uid);

    /**
     * 获取用户的个推标签
     * @param request 设备号相关信息
     * @return 标签列表
     */
    @PostMapping("/userService/getTagsForGetui")
    List<String> getTagsForGetui(@RequestBody DevRequest request);

    /**
     * 获取用户的个推标签<br/>
     *
     * @param uid {@link UserService#getUser(DevRequest) }
     * @return java.util.List<java.lang.String>
     */
    @RequestMapping(path = "/userService/getTagsForGetuiByUid", method = RequestMethod.GET)
    List<String> getTagsForGetuiByUid(@RequestParam(value = "uid", required = true) String uid);


    /**
     * 获取用户的个推标签 根据IPV6)
     * @param uid
     * @param ipv6
     * @return 标签列表
     */
    @PostMapping("/userService/getTagsForGetuiIpV6")
    void saveTagsForGetui(@RequestParam(value = "uid", required = true) String uid,
                          @RequestParam(value = "ipv6", required = true) String ipv6);

    /**
     * 获取用户的个推标签<br/>
     *
     * @param uid
     * @return GeTuiTagsEntity
     */
    @RequestMapping(path = "/userService/getTagsForGetuiIPV6ByUid", method = RequestMethod.GET)
    GeTuiTagsEntity getTagsForGetuiIPV6ByUid(@RequestParam(value = "uid", required = true) String uid);
}
